print("Initializing shulker")

from shulker import server, components, functions

__all__ = ["server", "components", "functions"]

"""# Classes
from .server.connect import RconClient as connect
from .server.create import DockerInstance as create
from .components import *
from .functions import *

# Functions
from .functions.set_text import set_text, _set_text
from .functions.set_zone import set_zone, _set_zone
from .functions.set_block import set_block, _set_block
from .functions.set_image import set_image, _set_image, print_palette

# Objects
from .server.singleton import singleton

post = singleton.post"""
